@@ -3,7 +3,7 @@
 
  Lincoln Stein <lincoln.stein@gmail.com>
  Ben Faga <ben.faga@gmail.com>
- $Id: controller.js 24408 2011-01-22 17:14:49Z lstein $
+ $Id: controller.js 24433 2011-01-27 12:26:09Z lstein $
 
 Indentation courtesy of Emacs javascript-mode 
 (http://mihai.bazon.net/projects/emacs-javascript-mode/javascript.el)
@@ -910,6 +910,57 @@ var GBrowseController = Class.create({
             detailsdiv.show();
         }
     },
+
+
+    show_info_message:
+    function (action,width) {
+        if (width == null) width=300;
+	var dim     = document.body.getDimensions();
+	var info = $('info_container');
+	if (info == null) {
+	    info        = new Element('div',{id:'info_container'});
+	    info.setStyle({position: 'absolute',
+			   zIndex:   100000,
+			   display:'none'});
+	    document.body.appendChild(info);
+
+	    var abs_container = new Element('div',{id:'abs_info_container'});
+	    info.appendChild(abs_container);
+
+	    var content = new Element('div',{id:'info_content'});
+	    abs_container.appendChild(content);
+	    var button = new Element('input',{type:'button',
+					      style:'float:right',
+					      id:'info_button',
+					      value:this.translate('OK')});
+	    // button.insert('&nbsp;'); // needed to close tag
+	    button.observe('click',function(ev) {$('info_container').hide()});
+	    content.insert({after:button});
+	}
+	// double containment necessary to avoid IE zindex bug!
+	$('info_container').setStyle( {
+		position: 'absolute',
+		backgroundColor: 'white',
+	        top:      '50px',
+		left:     Math.round((dim.width-width)/4)+'px',
+		zIndex:   10000,
+		width:   width+'px'
+	    });
+        $('abs_info_container').setStyle( {
+		position: 'absolute',
+		backgroundColor: 'white',
+	        top:      '0px',
+		left:     '0px',
+		border:   'double',
+		padding: '5px',
+		zIndex:  100001
+	    });
+	new Ajax.Updater('info_content',
+			 document.URL,{ 
+			     parameters: { action: action } ,
+			     onSuccess: function (t) { $('info_container').show()}
+	});
+    },
     
     edit_upload_title:
     function(upload_name, title_element) {
