@@ -1,6 +1,6 @@
 package Bio::Graphics::Browser2::CachedTrack;
 
-# $Id: CachedTrack.pm 23163 2010-05-09 14:05:19Z lstein $
+# $Id: CachedTrack.pm 24333 2011-01-05 22:31:41Z lstein $
 # This package defines a Bio::Graphics::Browser2::Track option that manages
 # the caching of track images and imagemaps.
 
@@ -109,14 +109,12 @@ sub lock {
     my $self    = shift;
     my $dotfile = $self->dotfile;
     my $tsfile  = $self->tsfile;
-    # my $error   = $self->errorfile;
     if (-e $dotfile) {  # if it exists, then either we are in process or something died
 	return if $self->status eq 'PENDING';
     }
-    # unlink $error if -e $error;
     my $f = IO::File->new(">$dotfile") or die "Can't open $dotfile for writing: $!";
     flock $f,LOCK_EX;
-    $f->print(time());
+    $f->print($$,' ',time());     # PID<sp>timestamp
     $f->close;
     return 1;
 }
@@ -151,11 +149,12 @@ sub errstr {
 }
 
 sub put_data {
-    my $self            = shift;
-    my ($gd,$map)       = @_;
-    $self->{data}{gd}   = $gd->can('gd2') ? $gd->gd2 : $gd;
-    $self->{data}{map}  = $map;
-    my $datafile        = $self->datafile;
+    my $self              = shift;
+    my ($gd,$map,$titles) = @_;
+    $self->{data}{gd}     = $gd->can('gd2') ? $gd->gd2 : $gd;
+    $self->{data}{map}    = $map;
+    $self->{data}{titles} = $titles;
+    my $datafile          = $self->datafile;
     store $self->{data},$datafile;
     $self->unlock;
     unlink $self->errorfile if -e $self->errorfile;
@@ -202,6 +201,12 @@ sub map {
     return $data->{map};
 }
 
+sub titles {
+    my $self = shift;
+    my $data = $self->get_data or return;
+    return $data->{titles};
+}
+
 sub width {
     my $self = shift;
     my $gd   = $self->gd or return;
@@ -222,11 +227,11 @@ sub height {
 # 'EXPIRED'   there is data, but it has expired
 # 'ERROR'     an error occurred, and data will never be available
 sub status {
-    my $self     = shift;
-    my $dir      = $self->cachedir;
-    my $dotfile  = $self->dotfile;
-    my $tsfile   = $self->tsfile;
-    my $datafile = $self->datafile;
+    my $self      = shift;
+    my $dir       = $self->cachedir;
+    my $dotfile   = $self->dotfile;
+    my $tsfile    = $self->tsfile;
+    my $datafile  = $self->datafile;
     my $errorfile = $self->errorfile;
 
     # if a dotfile exists then either we are in the midst of updating the
@@ -237,9 +242,13 @@ sub status {
 	my $f = IO::File->new($dotfile) 
 	    or return 'AVAILABLE'; # dotfile disappeared, so data has just become available
 	flock $f,LOCK_SH;
-	my $timestamp = $f->getline();
+	my ($pid,$timestamp) = split /\s+/,$f->getline();
 	$f->close;
 	return 'DEFUNCT' unless $timestamp;
+	unless (kill 0=>$pid) {
+	    $self->flag_error('the rendering process crashed');
+	    return 'ERROR';
+	}
 	return 'PENDING' if time()-$timestamp < $self->max_time;
 	$self->flag_error('timeout; try viewing a smaller region');
 	return 'ERROR';
